--[[

Version 0.15 - Added colour customisation of Aspect frame
Version 0.1 - Initial framework completed //wowace svn

Author : Auldare of EU Khadgar 
	
--]]

local L = LibStub("AceLocale-3.0"):GetLocale("AspectInspect")
local AceAddon = LibStub("AceAddon-3.0")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
AspectInspect = AceAddon:NewAddon("AspectInspect", "AceConsole-3.0", "AceEvent-3.0")
local REVISION = tonumber(("$Revision: 29 $"):match("%d+"))

AspectInspect.textures = {}
AspectInspect.borders = {}
AspectInspect.fonts = {}
AspectInspect.sounds = {}
AspectInspect.frameBackdrop ={
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		--edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
	}

local playerName=UnitName("player");

-------------------
-- Config details
-------------------

AspectInspect.defaults = {
	char = {
		message = "Welcome Home!",
		relativeTo = "UIParent",
		relativePoint = "CENTER",
		point = "CENTER",
		texture = "Blizzard",
		msgfont = "Friz Quadrata TT",
		msgfontsize = 24,
		msgfonteffect = "none",
		border = "None",
		barborder = "Blizzard Tooltip",
		xOffset = 0,
		yOffset = 0,
		fWidth = 300,
		fHeight = 175,
		scale = 1,
		debug = false,
		packwarning = true,
		cheetahwarning = true,
		manalowwarning = true,
		manahighwarning = true,
		manalowscale = 0.05,
		manahighscale = 0.95,
		colours = {
			aspecthawk = { r=0.2, g=0.2, b=0.8, a=0.2 },
			aspectdhawk = { r=0.8, g=0.2, b=0.8, a=0.2 },
			aspectmonkey = { r=0.1, g=0.1, b=0.1, a=0.4 },
			aspectviper = { r=0.1, g=0.9, b=0.8, a=0.2 },
			aspectpack = { r=0.9, g=0.9, b=0.9, a=0.2 },
			aspectcheetah = { r=0.9, g=0.9, b=0, a=0.2 },
			aspectbeast = { r=0.9, g=0, b=0, a=0.2 },
			aspectwild = { r=0.1, g=0.8, b=0.1, a=0.2 },
			noaspect = { r=0.2, g=0.2, b=0.8, a=0.8 },
		},
	}
}

-----------------------------------------
-- Initialisation & Startup Routines
-----------------------------------------

function AspectInspect:OnInitialize()
	local AceConfigReg = LibStub("AceConfigRegistry-3.0")
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")

	self.db = LibStub("AceDB-3.0"):New("AspectInspectDBPC", AspectInspect.defaults, "char")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("AspectInspect", self:GetOptions(), {"AspectInspect", "ai"} )
	media.RegisterCallback(self, "LibSharedMedia_Registered")
	
	-- Add the options to blizzard frame (add them backwards so they show up in the proper order
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("AspectInspect","AspectInspect")
	self.optionsFrame[L["About"]] = LibStub("LibAboutPanel").new("AspectInspect", "AspectInspect")
	self.db:RegisterDefaults(self.defaults)
	local version = GetAddOnMetadata("AspectInspect","Version")
	self.version = ("AspectInspect v%s (r%s)"):format(version, REVISION)
	self:Print(self.version.." Loaded.")
	self:Createaspectframe()
end

function AspectInspect:OnDisable()
    -- Called when the addon is disabled
end

function AspectInspect:OnEnable()
	self:LibSharedMedia_Registered()
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("UPDATE_BINDINGS")
	self:RegisterEvent("UNIT_AURA")
	self:RegisterEvent("PLAYER_REGEN_DISABLED")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("UNIT_MANA")
end

function AspectInspect:LibSharedMedia_Registered()
	for k, v in pairs(media:List("statusbar")) do
		self.textures[v] = v
	end
	for k, v in pairs(media:List("border")) do
		self.borders[v] = v
	end
	for k, v in pairs(media:List("font")) do
		self.fonts[v] = v
	end
	for k, v in pairs(media:List("sound")) do
		self.sounds[v] = v
	end
end

----------------------
-- Event Routines
----------------------

function AspectInspect:PLAYER_ENTERING_WORLD()
	self:SetFrameColor()
	if self.db.char.hideooc and not InCombatLockdown() then
	self.aspectframe:Hide()
	else
	self.aspectframe:Show()
	end
	-- does stuff when player zones
end

function AspectInspect:UPDATE_BINDINGS()
--~ 	self:UpdateBindings()
end

function AspectInspect:UNIT_AURA()
	if arg1 == "player" then
		self:SetFrameColor()
	end
end

function AspectInspect:PLAYER_REGEN_DISABLED()
	local aspectenabled,aspectname = self:CheckForAspect(L["Aspect"])
	self.aspectframe:Show()
	if aspectname == L["AspectCheetah"] and self.db.char.cheetahwarning == true then
		self:Print(L["combatstun"])
	elseif aspectname == L["AspectPack"] and self.db.char.packwarning == true then
		self:Print(L["combatstun"])
	end
end

function AspectInspect:PLAYER_REGEN_ENABLED()
	if self.db.char.hideooc then
		self.aspectframe:Hide()
	end
end

function AspectInspect:UNIT_MANA()
	local aspectenabled,aspectname = self:CheckForAspect(L["Aspect"])
	local Dhawklearnt = GetSpellInfo(L["AspectDragonhawk"])
	if arg1 == "player" then
	mpct = (UnitMana("player") / UnitManaMax("player"))
		if mpct <= self.db.char.manalowscale and self.db.char.manalowwarning == true then
			if aspectname == L["AspectHawk"] then
				self:Print(L["manalow"].." "..L["AspectViper"])
			elseif aspectname == L["AspectDragonhawk"] then
				self:Print(L["manalow"].." "..L["AspectViper"])
			end
		elseif mpct >= self.db.char.manahighscale and self.db.char.manahighwarning == true then
			if aspectname == L["AspectViper"] then
				if (Dhawklearnt == nil) then
				self:Print(L["manahigh"].." "..L["AspectHawk"])
				else
				self:Print(L["manahigh"].." "..L["AspectDragonhawk"])
				end
			end
		end
	end
end

function AspectInspect:SetFrameColor()
		local aspectenabled,aspectname = self:CheckForAspect(L["Aspect"])
		if aspectenabled then
			self:DebugPrint(aspectname.." "..L["yes"])
			local colours
			if aspectname == L["AspectHawk"] then
				colours = self.db.char.colours.aspecthawk
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectMonkey"] then
				colours = self.db.char.colours.aspectmonkey
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectDragonhawk"] then
				colours = self.db.char.colours.aspectdhawk
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectBeast"] then
				colours = self.db.char.colours.aspectbeast
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectCheetah"] then
				colours = self.db.char.colours.aspectcheetah
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectPack"] then
				colours = self.db.char.colours.aspectpack
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectWild"] then
				colours = self.db.char.colours.aspectwild
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
			elseif aspectname == L["AspectViper"] then
				colours = self.db.char.colours.aspectviper
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
	
			end
		else
			self:DebugPrint(L["noaspect"])
				colours = self.db.char.colours.noaspect
				self.aspectframe:SetBackdropColor(colours.r, colours.g, colours.b, colours.a)
		end
end

function AspectInspect:CheckForAspect(pattern)
	local index = 1
	while UnitBuff("player", index) do
		local name, _, _, count, _, _, _, isMine = UnitBuff("player", index)
		self:DebugPrint("Found buff "..name.." checking for "..pattern)
		if strmatch(name,pattern) and isMine then -- don't return true on finding another player's aspect
			return true, name
		end
		index = index + 1
	end
	return false
end

function AspectInspect:DebugPrint(msg)
	if self.db.char.debug then
		self:Print(msg)
	end
end

function AspectInspect:Createaspectframe()
	self.aspectframe=CreateFrame("Frame",nil,UIParent)
	self.aspectframe:SetHeight(200)
	self.aspectframe:SetWidth(200)
	self.aspectframe:SetFrameStrata("BACKGROUND")
	self.aspectframe:SetScale(1)
	self.aspectframe:SetBackdrop(AspectInspect.frameBackdrop)
	self.aspectframe:SetBackdropColor(0.6,0.6,0.6,0.75)
	self.aspectframe:SetPoint("CENTER",UIParent,"CENTER",0,0)
	self.aspectframe:Show()
end