local L = LibStub("AceLocale-3.0"):GetLocale("AspectInspect")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");

AspectInspect.fonteffects = {
	["none"] = L["none"],
	["OUTLINE"] = L["OUTLINE"],
	["THICKOUTLINE"] = L["THICKOUTLINE"],
	["MONOCHROME"] = L["MONOCHROME"],
}

function AspectInspect:GetOptions()
	local options = { 
		name = "AspectInspect",
		handler = AspectInspect,
		type = "group",
		childGroups = "tree",
		args = {
			debug = {
				type = 'toggle',
				name = L["Debug mode"],
				desc = L["help_debug"],
				get = "getDebug",
				set = "setDebug",
				guiHidden = true,
				order = 3,
			},
			config = {
				type = 'execute',
				name = L["Configure Options"],
				desc = L["help_config"],
				func = "OpenConfig",
				guiHidden = true,
				order = 4,
			},
			version = {
				type = 'execute',
				name = L["Version"],
				desc = L["help_version"],
				func = "DisplayVersion",
				order = 100,
			},
			help = {
				type = 'description',
				name = L["help"],
				guiHidden = true,
				order = 2,
			},
			hideooc= {
				type = 'toggle',
				name = L["Hide out of combat"],
				desc = L["help_hideooc"],
				get = "getHideooc",
				set = "setHideooc",
				order = 1,
			},
			colours = {
				name = L["Colour Options"],
				type = 'group',
				order = 6,
				args = {
					transaspect={
						type = 'range',
						min = 0,
						max = 1,
						name = L["Aspect Frame Alpha"],
						desc = L["coltransaspect"],
						get = "getAspectTrans",
						set = "setAspectTrans",
						order = 1,
					},
					transnoaspect={
						type = 'range',
						min = 0,
						max = 1,
						name = L["No Aspect Frame Alpha"],
						desc = L["coltransnoaspect"],
						get = "getNoAspectTrans",
						set = "setNoAspectTrans",
						order = 2,
					},
					dhawk = {
						type = 'color',
						name = L["Aspect of Dhawk Colour"],
						desc = L["colAspectDhawk"],
						get = "getAspectDhawkColour",
						set = "setAspectDhawkColour",
						hasAlpha = false,
						order = 3,
					},
					viper = {
						type = 'color',
						name = L["Aspect of Viper Colour"],
						desc = L["colAspectViper"],
						get = "getAspectViperColour",
						set = "setAspectViperColour",
						hasAlpha = false,
						order = 4,
					},
					hawk = {
						type = 'color',
						name = L["Aspect of Hawk Colour"],
						desc = L["colAspectHawk"],
						get = "getAspectHawkColour",
						set = "setAspectHawkColour",
						hasAlpha = false,
						order = 5,
					},
					monkey = {
						type = 'color',
						name = L["Aspect of Monkey Colour"],
						desc = L["colAspectMonkey"],
						get = "getAspectMonkeyColour",
						set = "setAspectMonkeyColour",
						hasAlpha = false,
						order = 6,
					},
					pack = {
						type = 'color',
						name = L["Aspect of Pack Colour"],
						desc = L["colAspectPack"],
						get = "getAspectPackColour",
						set = "setAspectPackColour",
						hasAlpha = false,
						order = 7,
					},
					cheetah = {
						type = 'color',
						name = L["Aspect of Cheetah Colour"],
						desc = L["colAspectCheetah"],
						get = "getAspectCheetahColour",
						set = "setAspectCheetahColour",
						hasAlpha = false,
						order = 8,
					},
					beast = {
						type = 'color',
						name = L["Aspect of Beast Colour"],
						desc = L["colAspectBeast"],
						get = "getAspectBeastColour",
						set = "setAspectBeastColour",
						hasAlpha = false,
						order = 9,
					},
					wild = {
						type = 'color',
						name = L["Aspect of Wild Colour"],
						desc = L["colAspectWild"],
						get = "getAspectWildColour",
						set = "setAspectWildColour",
						hasAlpha = false,
						order = 10,
					},
					noaspect = {
						type = 'color',
						name = L["No Aspect Colour"],
						desc = L["colNoAspect"],
						get = "getNoAspectColour",
						set = "setNoAspectColour",
						hasAlpha = false,
						order = 11,
					},
				},
			},
			aspectwatch = {
				name = L["Aspectwatch"],
				desc = L["colAspectwatch"],
				type = "group",
				order = 7,
				args = {
					pack = {
						type = "toggle",
						name = L["Packwatch"],
						desc = L["colPackwatch"],
						get = "getPackWarning",
						set = "setPackWarning",
					order = 1,
					},
					cheetah = {
						type = "toggle",
						name = L["Cheetahwatch"],
						desc = L["colCheetahwatch"],
						get = "getCheetahWarning",
						set = "setCheetahWarning",
						order = 2,
					},
					manalow={
						type = 'range',
						isPercent = true,
						min = 0,
						max = 1,
						name = L["Manalowwatchpercent"],
						desc = L["colManalowwatchpercent"],
						get = "getManaLow",
						set = "setManaLow",
						order = 3,
					},
					manahigh={
						type = 'range',
						isPercent = true,
						min = 0,
						max = 1,
						name = L["Manahighwatchpercent"],
						desc = L["colManahighwatchpercent"],
						get = "getManaHigh",
						set = "setManaHigh",
						order = 4,
					},
					mlowwarn = {
						type = "toggle",
						name = L["Manalowwatch"],
						desc = L["colManalowwatch"],
						get = "getMlowWarning",
						set = "setMlowWarning",
						order = 5,
					},
					mhighwarn = {
						type = "toggle",
						name = L["Manahighwatch"],
						desc = L["colManahighwatch"],
						get = "getMhighWarning",
						set = "setMhighWarning",
						order = 6,
					},
				},
			},	
		},
	}
	return options
end

function AspectInspect:getDebug()
	return self.db.char.debug
end

function AspectInspect:setDebug()
	self.db.char.debug = not self.db.char.debug
	if (self.db.char.debug) then
		self:Print(L["config_debug_on"])
	else
		self:Print(L["config_debug_off"])
	end
end

function AspectInspect:getHideooc()
	return self.db.char.hideooc
end

function AspectInspect:setHideooc()
	self.db.char.hideooc = not self.db.char.hideooc
	if (self.db.char.hideooc) then
		self:Print(L["config_hideooc_on"])
	else
		self:Print(L["config_hideooc_off"])
	end
end

function AspectInspect:FinishedMoving(var, frame)
	local point, relativeTo, relativePoint, xOffset, yOffset = frame:GetPoint();
	var.point = point
	var.relativeTo = relativeTo
	var.relativePoint = relativePoint
	var.xOffset = xOffset
	var.yOffset = yOffset
end

function AspectInspect:GetWidth()
    return self.db.char.fWidth
end

function AspectInspect:GetScale()
    return self.db.char.scale
end

function AspectInspect:SetScale(info,newValue)
	self.db.char.scale = newValue
	self.BagFrame:SetScale(self.db.char.scale)
	self:Print("Scale set to : "..self.db.char.scale)
end

function AspectInspect:OpenConfig()
	  if InterfaceOptionsFrame_OpenToCategory then
	    InterfaceOptionsFrame_OpenToCategory("AspectInspect");
    else
        InterfaceOptionsFrame_OpenToFrame("AspectInspect");
    end
end

function AspectInspect:DisplayVersion()
	self:Print(self.version)
end

function AspectInspect:getAspectHawkColour(info)
	local colours = self.db.char.colours.aspecthawk
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectHawkColour(info,r,g,b)
	self.db.char.colours.aspecthawk.r = r
	self.db.char.colours.aspecthawk.g = g
	self.db.char.colours.aspecthawk.b = b
end

function AspectInspect:getAspectDhawkColour(info)
	local colours = self.db.char.colours.aspectdhawk
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectDhawkColour(info,r,g,b)
	self.db.char.colours.aspectdhawk.r = r
	self.db.char.colours.aspectdhawk.g = g
	self.db.char.colours.aspectdhawk.b = b
end

function AspectInspect:getAspectViperColour(info)
	local colours = self.db.char.colours.aspectviper
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectViperColour(info,r,g,b)
	self.db.char.colours.aspectviper.r = r
	self.db.char.colours.aspectviper.g = g
	self.db.char.colours.aspectviper.b = b
end

function AspectInspect:getAspectMonkeyColour(info)
	local colours = self.db.char.colours.aspectmonkey
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectMonkeyColour(info,r,g,b)
	self.db.char.colours.aspectmonkey.r = r
	self.db.char.colours.aspectmonkey.g = g
	self.db.char.colours.aspectmonkey.b = b
end

function AspectInspect:getAspectCheetahColour(info)
	local colours = self.db.char.colours.aspectcheetah
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectCheetahColour(info,r,g,b)
	self.db.char.colours.aspectcheetah.r = r
	self.db.char.colours.aspectcheetah.g = g
	self.db.char.colours.aspectcheetah.b = b
end

function AspectInspect:getAspectPackColour(info)
	local colours = self.db.char.colours.aspectpack
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectPackColour(info,r,g,b)
	self.db.char.colours.aspectpack.r = r
	self.db.char.colours.aspectpack.g = g
	self.db.char.colours.aspectpack.b = b
end

function AspectInspect:getAspectWildColour(info)
	local colours = self.db.char.colours.aspectwild
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectWildColour(info,r,g,b)
	self.db.char.colours.aspectwild.r = r
	self.db.char.colours.aspectwild.g = g
	self.db.char.colours.aspectwild.b = b
end

function AspectInspect:getAspectBeastColour(info)
	local colours = self.db.char.colours.aspectbeast
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setAspectWildColour(info,r,g,b)
	self.db.char.colours.aspectwild.r = r
	self.db.char.colours.aspectwild.g = g
	self.db.char.colours.aspectwild.b = b
end

function AspectInspect:getNoAspectColour(info)
	local colours = self.db.char.colours.noaspect
	return colours.r, colours.g, colours.b, colours.a
end

function AspectInspect:setNoAspectColour(info,r,g,b)
	self.db.char.colours.noaspect.r = r
	self.db.char.colours.noaspect.g = g
	self.db.char.colours.noaspect.b = b
end

function AspectInspect:getAspectTrans(info)
	local colours = self.db.char.colours.aspectdhawk
	return colours.a
end

function AspectInspect:setAspectTrans(info,a)
	self.db.char.colours.aspecthawk.a = a
	self.db.char.colours.aspectdhawk.a = a
	self.db.char.colours.aspectmonkey.a = a
	self.db.char.colours.aspectviper.a = a
	self.db.char.colours.aspectwild.a = a
	self.db.char.colours.aspectpack.a = a
	self.db.char.colours.aspectcheetah.a = a
	self.db.char.colours.aspectbeast.a = a
end

function AspectInspect:getNoAspectTrans(info)
	local colours = self.db.char.colours.noaspect
	return colours.a
end

function AspectInspect:setNoAspectTrans(info,a)
	self.db.char.colours.noaspect.a = a

end

function AspectInspect:getPackWarning()
	return self.db.char.packwarning
end

function AspectInspect:setPackWarning()
	self.db.char.packwarning = not self.db.char.packwarning
	if (self.db.char.packwarning) then
		self:Print(L["config_pack_on"])
	else
		self:Print(L["config_pack_off"])
	end
end

function AspectInspect:getCheetahWarning()
	return self.db.char.cheetahwarning
end

function AspectInspect:setCheetahWarning()
	self.db.char.cheetahwarning = not self.db.char.cheetahwarning
	if (self.db.char.cheetahwarning) then
		self:Print(L["config_cheetah_on"])
	else
		self:Print(L["config_cheetah_off"])
	end
end

function AspectInspect:getMlowWarning()
	return self.db.char.manalowwarning
end

function AspectInspect:setMlowWarning()
	self.db.char.manalowwarning = not self.db.char.manalowwarning
	if (self.db.char.manalowwarning) then
		self:Print(L["config_manalow_on"])
	else
		self:Print(L["config_manalow_off"])
	end
end

function AspectInspect:getMhighWarning()
	return self.db.char.manahighwarning
end

function AspectInspect:setMhighWarning()
	self.db.char.manahighwarning = not self.db.char.manahighwarning
	if (self.db.char.manahighwarning) then
		self:Print(L["config_manahigh_on"])
	else
		self:Print(L["config_manahigh_off"])
	end
end

function AspectInspect:getManaLow(info)
	return self.db.char.manalowscale
end

function AspectInspect:setManaLow(info, new_value)
	self.db.char.manalowscale = new_value
end

function AspectInspect:getManaHigh(info)
	return self.db.char.manahighscale
end

function AspectInspect:setManaHigh(info, new_value)
	self.db.char.manahighscale = new_value
end